uname(1)

uname - identify the current IRIX system

As shipped in IRIX 6.5. First release of IRIX 6.5.

NAME
     uname - identify the current IRIX system

SYNOPSIS
     uname [ -snrvmpadR ]

     uname [ -V INSTVERSIONNUM ]

     uname [ -S nodename ]

DESCRIPTION
     uname prints information that identifies the current IRIX system to
     standard output. The string IRIX64 is printed on systems with 64-bit
     kernels.  The options cause selected information returned by uname(2) to
     be printed:

     -a   Behave as though all of the options -mnrsv were specified.

     -m   Print the machine hardware name.  This is the type of CPU board that
          the system is running on, e.g.  IP22.

     -n   Print the hostname or nodename.  The nodename is the name by which
          the system is known to communications networks.

     -p   Print the (informal) name of the current system's instruction set
          architecture.  See the SI_ARCHITECTURE section of sysinfo(2).

     -r   Print the operating system release.  This string begins with one of
          the following forms:  m.n or m.n.a where m is the major release
          number, n is the minor release number and a is the (optional)
          maintenance level of the release; e.g.  3.2 or 3.2.1.

     -R   Print the extended release name, usually the name of a hardware
          specific release.  Implies the -r option.  The string returned will
          be empty (that is, the -r and -R options will produce the same
          output) on the base OS release.  This option shows additional
          information similar to that printed on the CD label for hardware
          specific releases.

     -s   Print the (operating) system name (the default).

     -v   Print the operating system version.  This is the date and time that
          the operating system was generated, and has the form:  mmddhhmm.

     The -d and -V options decode the inst version-number, a 10-digit integer
     that, if present, is the last field in the release-name string returned
     by `uname -r'.  Alpha, Beta, and Patch releases have inst version-
     numbers, MR releases do not.  This number represents encoded information
     about the origin of the release.
     `uname -d' attempts to report the running system's inst version
     information; if the release has no inst version-number, uname displays an
     error message.

     `uname -V INSTVERSIONNUM' interprets and displays the information encoded
     in INSTVERSIONNUM; if the number is invalid, uname displays an error
     message.

     The hostname or nodename may be changed by specifying an argument to the
     -S option.  Only the super-user is allowed this capability.

NOTES
     Do not confuse the 8-digit version number returned by `uname -v'--present
     in all releases--with the 10-digit inst version-number.  The two serve
     different--if somewhat overlapping--purposes.

SEE ALSO
     uname(2), sysinfo(2), inst(1M), versions(1M)